Concepts and terminology
========================

The following concepts define how data is organised, accessed, and catalogued by Rucio.

.. toctree::
    :maxdepth: 1

    overview_Rucio_account
    overview_File_Dataset_Container
    overview_Meta-data_attributes
    overview_Rucio_Storage_Element
    overview_Permission_model
    overview_Replica_management
    replication_rules_examples
    RSE_Expressions
    overview_Accounting_and_quota
    overview_Notifications
    overview_Subscriptions
